@@ -19,7 +19,7 @@
 #' @param version A character vector indicating the version of the GSW data set
 #'   to make available.
 #' @keywords resource
-#' @returns A function that returns a character of file paths.
+#' @returns A function that returns an `sf` footprint object.
 #' @references Pekel, JF., Cottam, A., Gorelick, N. et al. High-resolution
 #' mapping of global surface water and its long-term changes. Nature 540,
 #' 418–422 (2016). https://doi.org/10.1038/nature20584
@@ -33,12 +33,8 @@ get_global_surface_water_change <- function(version = "v1_4_2021") {
            name = "global_surface_water_change",
            type = "raster",
            outdir = mapme_options()[["outdir"]],
-           verbose = mapme_options()[["verbose"]],
-           testing = mapme_options()[["testing"]]) {
-    .get_gsw(x,
-      statistic = "change", version = version,
-      dir = outdir, verbose = verbose
-    )
+           verbose = mapme_options()[["verbose"]]) {
+    .get_gsw(x, statistic = "change", version = version)
   }
 }
 #' Global Surface Water Transitions
@@ -85,12 +81,8 @@ get_global_surface_water_transitions <- function(version = "v1_4_2021") {
            name = "global_surface_water_transitions",
            type = "raster",
            outdir = mapme_options()[["outdir"]],
-           verbose = mapme_options()[["verbose"]],
-           testing = mapme_options()[["testing"]]) {
-    .get_gsw(x,
-      statistic = "transitions", version = version,
-      dir = outdir, verbose = verbose
-    )
+           verbose = mapme_options()[["verbose"]]) {
+    .get_gsw(x, statistic = "transitions", version = version)
   }
 }
 
@@ -125,12 +117,8 @@ get_global_surface_water_seasonality <- function(version = "v1_4_2021") {
            name = "global_surface_water_seasonality",
            type = "raster",
            outdir = mapme_options()[["outdir"]],
-           verbose = mapme_options()[["verbose"]],
-           testing = mapme_options()[["testing"]]) {
-    .get_gsw(x,
-      statistic = "seasonality", version = version,
-      dir = outdir, verbose = verbose
-    )
+           verbose = mapme_options()[["verbose"]]) {
+    .get_gsw(x, statistic = "seasonality", version = version)
   }
 }
 
@@ -168,12 +156,8 @@ get_global_surface_water_recurrence <- function(version = "v1_4_2021") {
            name = "global_surface_water_recurrence",
            type = "raster",
            outdir = mapme_options()[["outdir"]],
-           verbose = mapme_options()[["verbose"]],
-           testing = mapme_options()[["testing"]]) {
-    .get_gsw(x,
-      statistic = "recurrence", version = version,
-      dir = outdir, verbose = verbose
-    )
+           verbose = mapme_options()[["verbose"]]) {
+    .get_gsw(x, statistic = "recurrence", version = version)
   }
 }
 
@@ -210,17 +194,12 @@ get_global_surface_water_occurrence <- function(version = "v1_4_2021") {
            name = "global_surface_water_occurrence",
            type = "raster",
            outdir = mapme_options()[["outdir"]],
-           verbose = mapme_options()[["verbose"]],
-           testing = mapme_options()[["testing"]]) {
-    .get_gsw(x,
-      statistic = "occurrence", version = version,
-      dir = outdir, verbose = verbose
-    )
+           verbose = mapme_options()[["verbose"]]) {
+    .get_gsw(x, statistic = "occurrence", version = version)
   }
 }
 
-.get_gsw <- function(x, statistic = "occurrence", version = "v1_4_2021",
-                     dir = tempdir(), verbose = TRUE) {
+.get_gsw <- function(x, statistic = "occurrence", version = "v1_4_2021") {
   stopifnot(
     statistic %in% .gsw_statistics,
     version %in% .gsw_versions
@@ -228,7 +207,7 @@ get_global_surface_water_occurrence <- function(version = "v1_4_2021") {
 
   # make the gsw grid and construct urls for intersecting tiles
   baseurl <- sprintf(
-    "https://storage.googleapis.com/global-surface-water/downloads2021/%s/%s",
+    "/vsicurl/https://storage.googleapis.com/global-surface-water/downloads2021/%s/%s",
     statistic, statistic
   )
   grid_gfc <- make_global_grid(
@@ -242,18 +221,12 @@ get_global_surface_water_occurrence <- function(version = "v1_4_2021") {
     )
   }
   ids <- sapply(tile_ids, function(n) .get_gsw_tile_id(grid_gfc[n, ]))
-  urls <- sprintf(
-    "%s_%s%s.tif",
-    baseurl, ids, version
-  )
-  filenames <- file.path(dir, basename(urls))
-  if (mapme_options()[["testing"]]) {
-    return(filenames)
-  }
-  # start download and skip files that exist
-  download_or_skip(urls, filenames, check_existence = FALSE)
-  # return all paths to the downloaded files
-  filenames
+  urls <- sprintf("%s_%s%s.tif", baseurl, ids, version)
+
+  fps <- grid_gfc[tile_ids, ]
+  fps[["source"]] <- urls
+
+  make_footprints(fps, what = "raster", co = c("-co", "COMPRESS=LZW", "-ot", "Byte"))
 }
 
 .get_gsw_tile_id <- function(tile) {
